## Overview
Handy utilities mainly for computer vision


## Installation

khandy requires Python 3.8 or higher. 

### Install the latest stable version from PyPI
```sh
pip install -U khandy
```

### Install the latest version from the master branch on GitHub
```sh
pip install -U git+https://github.com/quarrying/khandy.git
```

### Install the latest version locally
```sh
git clone https://github.com/quarrying/khandy.git
cd khandy
pip install -e .
```


## Dependencies
One of the principles of this project is to ensure minimal dependencies. Now only depends:

- NumPy 1.11+
- OpenCV 2.0+
- Pillow
- lxml
- requests

